@@ -1,13 +1,7 @@
-package Dist::Zilla::Plugin::Test::CheckDeps;
-{
-  $Dist::Zilla::Plugin::Test::CheckDeps::VERSION = '0.012';
-}
-# git description: v0.011-5-g6f4c027
+package Dist::Zilla::Plugin::Test::CheckDeps; # git description: v0.012-22-g830c81b
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-BEGIN {
-  $Dist::Zilla::Plugin::Test::CheckDeps::AUTHORITY = 'cpan:ETHER';
-}
-# vim: set ts=4 sw=4 tw=78 et nolist :
+our $VERSION = '0.013';
 
 use Moose;
 extends qw/Dist::Zilla::Plugin::InlineFiles/;
@@ -39,6 +33,20 @@ has filename => (
     default => 't/00-check-deps.t',
 );
 
+around dump_config => sub {
+    my $orig = shift;
+    my $self = shift;
+
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        (map { $_ => $self->$_ } qw(todo_when level filename)),
+        fatal => $self->fatal ? 1 : 0,
+    };
+
+    return $config;
+};
+
 around add_file => sub {
     my ($orig, $self, $file) = @_;
 
@@ -66,19 +74,59 @@ __PACKAGE__->meta->make_immutable;
 
 # ABSTRACT: Check for presence of dependencies
 
+#pod =pod
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod  [Test::CheckDeps]
+#pod  fatal = 0          ; default
+#pod  level = classic
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This module adds a test that assures all dependencies have been installed properly. If requested, it can bail out all testing on error.
+#pod
+#pod This plugin accepts the following options:
+#pod
+#pod =for stopwords TODO
+#pod
+#pod =over 4
+#pod
+#pod =item * C<todo_when>: a code string snippet (evaluated when the test is run)
+#pod to indicate when failing tests should be considered L<TODO|Test::More/Conditional tests>,
+#pod rather than genuine fails -- default is '0' (tests are never C<TODO>).
+#pod
+#pod Other suggested values are:
+#pod
+#pod     todo_when = !$ENV{AUTHOR_TESTING} && !$ENV{AUTOMATED_TESTING}
+#pod     todo_when = $^V < '5.012'   ; CPAN.pm didn't reliably read META.* before this
+#pod
+#pod =item * C<fatal>: if true, C<BAIL_OUT> is called if the tests fail. Defaults
+#pod to false.
+#pod
+#pod =item * C<level>: passed to C<check_dependencies> in L<Test::CheckDeps>.
+#pod (Defaults to C<classic>.)
+#pod
+#pod =item * C<filename>: the name of the generated file. Defaults to
+#pod F<t/00-check-deps.t>.
+#pod
+#pod =back
+#pod
+#pod =for Pod::Coverage register_prereqs
+#pod
+#pod =cut
+
 =pod
 
 =encoding UTF-8
 
-=for :stopwords Leon Timmermans Brendan Byrd Karen Etheridge TODO
-
 =head1 NAME
 
 Dist::Zilla::Plugin::Test::CheckDeps - Check for presence of dependencies
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -92,6 +140,8 @@ This module adds a test that assures all dependencies have been installed proper
 
 This plugin accepts the following options:
 
+=for stopwords TODO
+
 =over 4
 
 =item * C<todo_when>: a code string snippet (evaluated when the test is run)
@@ -120,31 +170,33 @@ F<t/00-check-deps.t>.
 
 Leon Timmermans <leont@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Leon Timmermans.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Leon Timmermans Brendan Byrd
+
 =over 4
 
 =item *
 
-Brendan Byrd <GitHub@ResonatorSoft.org>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
 Leon Timmermans <fawaka@gmail.com>
 
+=item *
+
+Brendan Byrd <GitHub@ResonatorSoft.org>
+
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Leon Timmermans.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __DATA__
@@ -152,7 +204,7 @@ ___[ test-checkdeps ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 
 use Test::More 0.94;
 {{
